@@ -1,5 +1,6 @@
 # frozen_string_literal: true
 
+require "test_prof/core"
 require "test_prof/factory_bot"
 require "test_prof/factory_all_stub/factory_bot_patch"
 
@@ -11,7 +12,7 @@ module TestProf
 
     class << self
       def init
-        # Monkey-patch FactoryBot / FactoryGirl
+        # Monkey-patch FactoryBot
         TestProf::FactoryBot::FactoryRunner.prepend(FactoryBotPatch) if
           defined?(TestProf::FactoryBot)
       end
