@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require_relative "./base"
+require "test_prof/rspec_dissect/collectors/base"
 
 module TestProf
   module RSpecDissect
@@ -29,7 +29,7 @@ module TestProf
             .sort_by(&:last)
             .take(RSpecDissect.config.let_top_count)
             .each do |(id, size)|
-            msgs << " ↳ #{id} – #{-size}\n"
+              msgs << " ↳ #{id} – #{-size}\n"
           end
           msgs.join
         end
